<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Relic EDD Store
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments-area">

	<?php
	// You can start editing here -- including this comment!
	if ( have_comments() ) :
		?>
		<h2 class="comments-title my-5">
			<?php
			$relic_edd_store_comment_count = get_comments_number();
			if ( '1' === $relic_edd_store_comment_count ) {
					/* translators: 1: title. */
				echo	esc_html__( 'One Comment','relic-edd-store');
			} else {
				$relic_edd_store_comment = $relic_edd_store_comment_count. esc_html__( 'Comment','relic-edd-store');
				echo esc_html( $relic_edd_store_comment );
			}
			?>
		</h2><!-- .comments-title -->

		<?php the_comments_navigation(); ?>

		<ol class="comment-list">
			<?php wp_list_comments( 'type=comment&callback=relic_edd_store_comment_list' ); ?>
		</ol><!-- .comment-list -->

		<?php
		the_comments_navigation();

		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() ) :
			?>
			<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'relic-edd-store' ); ?></p>
			<?php
		endif;

	endif; // Check for have_comments().

	comment_form();
	?>

</div><!-- #comments -->

<?php
function relic_edd_store_comment_list($relic_edd_store_comment, $args, $depth) {
    if ( 'div' === $args['style'] ) {
        $tag       = 'div';
        $add_below = 'comment';
    } else {
        $tag       = 'li';
        $add_below = 'div-comment';
    }?>
    <<?php echo esc_attr( $tag ); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID() ?>"><?php 
    if ( 'div' != $args['style'] ) { ?>
        <div id="div-comment-<?php comment_ID() ?>" class="comment-body"><div class="row"><?php } ?>
    	<div class="col-lg-2">
	        <div class="comment-author vcard"><?php 
	            if ( $args['avatar_size'] != 0 ) {
	                echo get_avatar( $relic_edd_store_comment, $args['avatar_size'] ); 
	            }
	        ?>
	        </div>
	       </div>
	       <?php 
        if ( $relic_edd_store_comment->comment_approved == '0' ) { ?>
            <em class="comment-awaiting-moderation"><?php  echo esc_html__( 'Your comment is awaiting moderation.','relic-edd-store' ); ?></em><br/><?php } ?>
        <div class="col-lg-10">
	        <div class="comment-details">
	        	<div class="comment-says">
	        		<?php
	        			printf( wp_kses_post( '<cite class="fn">%s</cite> <span class="says">says:</span>','relic-edd-store' ), get_comment_author_link() );
	        		?>
	        	</div>
		        <div class="comment-meta commentmetadata">
		            <a href="<?php echo esc_url( htmlspecialchars( get_comment_link( $relic_edd_store_comment->comment_ID ) ) ); ?>"><?php
		                /* translators: 1: date, 2: time */
		                printf( 
		                    esc_html('%1$s at %2$s'), 
		                    esc_html( get_comment_date() ),  
		                    esc_html( get_comment_time() )
						); 
						?>
		            </a><?php 
		            edit_comment_link( __( '(Edit)','relic-edd-store' ), '  ', '' ); ?>
		        </div>

		        <?php comment_text(); ?>
		     </div>

 			
        <div class="reply"><?php 
                comment_reply_link( 
                    array_merge( 
                        $args, 
                        array( 
                            'add_below' => $add_below, 
                            'depth'     => $depth, 
                            'max_depth' => $args['max_depth'] 
                        ) 
                    ) 
                ); ?>
        </div>
        </div> </div><?php 
    if ( 'div' != $args['style'] ) : ?>
        </div><?php 
    endif;
}