<?php
/**
 * The functions
 *
 * @package     Relic EDD Store
 * @author     	themerelic
 * @copyright   Copyright (c) 2019, themerelic
 * @link        http://themerelic.com
 * @since       Relic EDD Store 1.0.0
 * */
/**
 * Define Constants
 * @since 1.0.0
 */
define( 'RELIC_EDD_STORE_THEME_VERSION', '1.0.0' );
define( 'RELIC_EDD_STORE_THEME_DIR', trailingslashit ( get_template_directory() ) );
define( 'RELIC_EDD_STORE_THEME_URI', trailingslashit ( get_template_directory_uri() ));
define( 'RELIC_EDD_STORE_THEME_IMG', trailingslashit ( get_template_directory_uri() ). 'assets/images/' );

/**
 * required after setup section,
 * section is 
 * 
 * @since 1.0.0
 */
require_once RELIC_EDD_STORE_THEME_DIR . 'themerelic/core/class-relic-edd-store-after-setup-theme.php';
require_once RELIC_EDD_STORE_THEME_DIR . 'themerelic/core/class-register-widget.php';
require_once RELIC_EDD_STORE_THEME_DIR . 'themerelic/core/class-relic-edd-store-enqueue-scripts.php';

/**
 * Default Require File
 * @since 1.0.0
 */
require RELIC_EDD_STORE_THEME_DIR . 'themerelic/inc/custom-header.php';
require RELIC_EDD_STORE_THEME_DIR . 'themerelic/inc/template-tags.php';
require RELIC_EDD_STORE_THEME_DIR . 'themerelic/inc/template-functions.php';
require RELIC_EDD_STORE_THEME_DIR . 'themerelic/inc/customizer.php';



/**
 * Hooks file
 * @since 1.0.0
 */
require RELIC_EDD_STORE_THEME_DIR . 'themerelic/hooks/edd-store-functions.php';



/**
 * Customizer Settings
 */
require RELIC_EDD_STORE_THEME_DIR . '/themerelic/customizer/custom-controls/custom-control.php';
require RELIC_EDD_STORE_THEME_DIR . '/themerelic/customizer/customizer.php';
require RELIC_EDD_STORE_THEME_DIR . '/themerelic/customizer/edd-customizer-callback.php';

/*=========================================================================
 * Breadcrumb Trail - A breadcrumb menu script for WordPress.
==========================================================================*/
require RELIC_EDD_STORE_THEME_DIR . '/themerelic/compatibility/class-breadcrumb-trail.php';


/*=========================================================================
 * 	TGM-Plugin-Activation
==========================================================================*/
require RELIC_EDD_STORE_THEME_DIR . '/themerelic/compatibility/class-tgm-plugin-activation.php';
require RELIC_EDD_STORE_THEME_DIR . '/themerelic/inc/plugin-required.php';

add_action('edd_checkout_form_top','relic_edd_store_cart_items_before_div',10);
function relic_edd_store_cart_items_before_div(){
	echo '<div class="edd-store-frontpage-section">';
}


add_action('edd_checkout_form_bottom','relic_edd_store_cart_items_after_div',50);
function relic_edd_store_cart_items_after_div(){
	echo '</div>';
}



add_action('edd_downloads_list_top','relic_edd_store_edd_downloads_list_top');
function relic_edd_store_edd_downloads_list_top(){
	echo "<div class='row'>";
}

add_action('edd_downloads_list_bottom','relic_edd_store_edd_downloads_list_bottom');
function relic_edd_store_edd_downloads_list_bottom(){
	echo "</div>";
}



//Easy_Digital_Downloads Activation
function relic_edd_store_is_activated() {
	return class_exists( 'Easy_Digital_Downloads' ) ? true : false;
}

function relic_edd_store_archive_per_page( $query ) {
	if( isset($_GET['post_per_page'])){
		$relic_edd_store_post_per_page = intval( wp_unslash( $_GET['post_per_page'] ) ); // ...
		$query->set( 'posts_per_page', $relic_edd_store_post_per_page);
	}
}
add_filter( 'pre_get_posts', 'relic_edd_store_archive_per_page' );

add_filter( 'posts_where', 'relic_edd_store_posts_where', 10, 2 );
function relic_edd_store_posts_where( $where, $wp_query ){
	global $wpdb;
	if( isset($_GET['title'])){
		$relic_edd_store_title = sanitize_title( wp_unslash( $_GET['title'] ) ); // ...
		if ( isset($relic_edd_store_title) ) {	
			$where .= ' AND ' . $wpdb->posts . '.post_title LIKE \'' . esc_sql(  $relic_edd_store_title ) . '%\'';
		}
	}
    return $where;
}


/**
 * Add login logout menu item in the main menu.
 * ===========================================
 */
add_filter( 'wp_nav_menu_items', 'relic_edd_store_add_loginout_link', 10, 2 );
function relic_edd_store_add_loginout_link( $items, $args ) {
    /**
     * If menu primary menu is set & user is logged in.
     */
    if ( is_user_logged_in() && $args->theme_location == 'user-profile' ) {
        $items .= '<li><a href="'.esc_url(  wp_logout_url()  ).'"><i class="fa fa-sign-out" aria-hidden="true"></i>'.esc_html__('Log Out','relic-edd-store').'</a></li>';
    }
    /**
     * Else display login menu item.
     */
    elseif ( !is_user_logged_in() && $args->theme_location == 'user-profile' ) {
		$items = '<li><a href="'.esc_url( get_site_url(null, '/login') ).'"><i class="fa fa-sign-in" aria-hidden="true"></i>'.esc_html__('Login','relic-edd-store').'</a></li>';
		$items .= '<li><a href="'.esc_url( get_site_url(null, '/register') ).'"><i class="fa fa-user" aria-hidden="true"></i> '.esc_html__('Register','relic-edd-store').'</a></li>';
    }
    return $items;
}


/**
 * Limite the excerpt
 * 
 * @since 1.0.4
 */
function relic_edd_store_excerpt_length( $length ) {

	if(is_admin() && !defined('DOING_AJAX') ){
		return $length;
	}

	return absint( get_theme_mod('relic_edd_store_the_excerpt_word_limit',10) );
}
add_filter( 'excerpt_length','relic_edd_store_excerpt_length', 999 );
