<?php
/**
 * Themerelic functions and definitions.
 * Text Domain: edd-store
 * When using a child theme (see http://codex.wordpress.org/Theme_Development
 * and http://codex.wordpress.org/Child_Themes), you can override certain
 * functions (those wrapped in a function_exists() call) by defining them first
 * in your child theme's functions.php file. The child theme's functions.php
 * file is included before the parent theme's file, so the child theme
 * functions would be used.
 *
 * For more information on hooks, actions, and filters,
 * see http://codex.wordpress.org/Plugin_API
 *
 *  Relic EDD Store is a very powerful theme and virtually anything can be customized
 * via a child theme.
 *
 *
 * @package     Relic EDD Store
 * @author     	themerelic
 * @copyright   Copyright (c) 2019, themerelic
 * @link        http://themerelic.com
 * @since       Relic EDD Store 1.0.0
 * */


/**
 * Relic_Edd_Store_After_Setup_Theme initial setup
 *
 * @since 1.0.0
 */
if ( ! class_exists( 'Relic_Edd_Store_After_Setup_Theme' ) ) {

	/**
	 * Relic_Edd_Store_After_Setup_Theme initial setup
	 */
	class Relic_Edd_Store_After_Setup_Theme {

		/**
		 * Instance
		 *
		 * @var $instance
		 */
		private static $instance;

		/**
		 * Initiator
		 *
		 * @since 1.0.0
		 * @return object
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self;
			}
			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {
			add_action( 'after_setup_theme', array( $this, 'relic_edd_store_setup_theme' ), 2 );
            add_action( 'admin_init',array($this,'relic_edd_store_add_editor_styles')  );
            add_action( 'after_setup_theme',array($this,'relic_edd_store_content_width') , 0 );
        }

		/**
		 * Setup theme
		 *
		 * @since 1.0.0
		 */
		function relic_edd_store_setup_theme() {
			/*
			 * Make theme available for translation.
			 * Translations can be filed in the /languages/ directory.
			 * If you're building a theme based on themerelic, use a find and replace
			 * to change 'relic-edd-store' to the name of your theme in all the template files.
			 */
			load_theme_textdomain( 'relic-edd-store', get_template_directory() . '/languages' );

			// Add default posts and comments RSS feed links to head.
			add_theme_support( 'automatic-feed-links' );

			/*
			 * Let WordPress manage the document title.
			 * By adding theme support, we declare that this theme does not use a
			 * hard-coded <title> tag in the document head, and expect WordPress to
			 * provide it for us.
			 */
			add_theme_support( 'title-tag' );

			/*
			 * Enable support for Post Thumbnails on posts and pages.
			 *
			 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
			 */
			add_theme_support( 'post-thumbnails' );


			/**
			 * Add the Images Size
			 * 
			 * @since 1.0.0
			 */
			add_image_size( 'relic_edd_store_theme_list', 330, 250 ); // 


			// This theme uses wp_nav_menu() in one location.
			register_nav_menus( array(
				'menu-1' 		=> esc_html__( 'Primary', 'relic-edd-store' ),
				'user-profile'	=> esc_html__('User Menu','relic-edd-store'),
			) );

			/*
			 * Switch default core markup for search form, comment form, and comments
			 * to output valid HTML5.
			 */
			add_theme_support( 'html5', array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			) );

			// Set up the WordPress core custom background feature.
			add_theme_support( 'custom-background', apply_filters( 'relic_edd_store_custom_background_args', array(
				'default-color' => 'ffffff',
				'default-image' => '',
			) ) );

			// Add theme support for selective refresh for widgets.
			add_theme_support( 'customize-selective-refresh-widgets' );

			/**
			 * Add support for core custom logo.
			 *
			 * @link https://codex.wordpress.org/Theme_Logo
			 */
			add_theme_support( 'custom-logo', array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			) );
        }



        /**
		 * Registers an editor stylesheet for the theme.
         * 
         * @since 1.0.0
		 */
		function relic_edd_store_add_editor_styles() {
			add_editor_style( 'edd-store-custom' );
        }


        /**
         * Set the content width in pixels, based on the theme's design and stylesheet.
         *
         * Priority 0 to make it available to lower priority callbacks.
         *
         * @global int $relic_edd_store_content_width
         */
        function relic_edd_store_content_width() {
            // This variable is intended to be overruled from themes.
            // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
            // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
            $GLOBALS['content_width'] = apply_filters( 'relic_edd_store_content_width', 640 );
        }
    }
}
/**
 * cicking this off by calling 'get_instance()' method
 */
Relic_Edd_Store_After_Setup_Theme::get_instance();