<?php
/**
 * General Settings
 *
 * @package     Relic EDD Store
 * @author     	themerelic
 * @copyright   Copyright (c) 2019, themerelic
 * @link        http://themerelic.com
 * @since       Relic EDD Store 1.0.0
 * */
function relic_edd_store_customize_general_settings( $wp_customize ) {
	
    /**
    * General Settings Panel
    */
    /** Enable/Disable Top Header Settings */
    $wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
    $wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
    $wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

    /** Relic EDD Store Logo Customizer */
    if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'blogname', array(
            'selector'        => '.site-title a',
            'render_callback' => 'relic_edd_store_customize_partial_blogname',
        ) );
        $wp_customize->selective_refresh->add_partial( 'blogdescription', array(
            'selector'        => '.site-description',
            'render_callback' => 'relic_edd_store_customize_partial_blogdescription',
        ) );
    }

    //Relic EDD Store Logo Setting
    $wp_customize->get_section('title_tagline')->panel = 'general_setting';
    $wp_customize->get_section('title_tagline' )->priority = 1;


    $wp_customize->get_section('header_image')->panel = 'general_setting';
    $wp_customize->get_section('header_image' )->priority = 2;

    $wp_customize->get_section('title_tagline' )->priority = 3;

     /**
    * General Settings Panel
    * @since 1.0.0
    */
    $wp_customize->get_section('colors')->panel = 'general_setting';
    $wp_customize->get_control('header_textcolor' )->priority = 6;
    $wp_customize->get_control('background_color' )->priority = 7;
    $wp_customize->get_section('background_image')->panel = 'general_setting';

    /**
     * Header Section
     * @since 1.0.0
     */
    $wp_customize->add_section( 'relic_edd_store_basic_header_section', array(
        'title'    => esc_html__( 'Header Section', 'relic-edd-store' ),
        'priority' => 82,
        'panel'    =>'general_setting'
    ) );
    $wp_customize->add_setting( 
        'relic_edd_store_header_layout_select', 
        array(
            'default'           => esc_html__('header-two','relic-edd-store' ),
            'sanitize_callback' => 'relic_edd_store_sec_sanitize_select'
        )
    );
    $wp_customize->add_control( 
        'relic_edd_store_header_layout_select', 
        array(
            'label' => esc_html__( 'Header  Layout', 'relic-edd-store' ),
            'section' => 'relic_edd_store_basic_header_section',
            'type' => 'select',
            'choices' =>array(
                'header-one'  =>  esc_html__( 'Header One', 'relic-edd-store' ),
                'header-two'  =>  esc_html__( 'Header Two', 'relic-edd-store' ),
            ),
            'priority'    => 3,
        )
    );

    /**
     * Footer Widget enable
     * @since 1.0.0
     */
    $wp_customize->add_section( 'relic_edd_store_basic_footer_section', array(
        'title'    => esc_html__( 'Footer Section', 'relic-edd-store' ),
        'priority' => 82,
        'panel'    =>'general_setting'
    ) );
    $wp_customize->add_setting(
        'relic_edd_store_footer_widget_enable',
        array(
            'default'           => true,
            'sanitize_callback' => 'relic_edd_store_sanitize_checkbox',
        )
    );
    $wp_customize->add_control(
		new Relic_Edd_Store_Toggle_Control( 
			$wp_customize,
			'relic_edd_store_footer_widget_enable',
			array(
				'section'	  => 'relic_edd_store_basic_footer_section',
				'label'		  => esc_html__( 'Disable Advance Footer Widget Enable', 'relic-edd-store' ),
                'description' => esc_html__( 'Enable/Disable Advance Footer Widget Enable.', 'relic-edd-store' ),
                'priority'    => 1
			)
		)
    );

    
}
add_action( 'customize_register', 'relic_edd_store_customize_general_settings' );