<?php
/**
 * Template functions
 *
 * @package     Relic EDD Store
 * @author     	themerelic
 * @copyright   Copyright (c) 2019, themerelic
 * @link        http://themerelic.com
 * @since       Relic EDD Store 1.0.0
 * */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $relic_edd_store_classes Classes for the body element.
 * @return array
 */
function relic_edd_store_body_classes( $relic_edd_store_classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$relic_edd_store_classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$relic_edd_store_classes[] = 'no-sidebar';
	}

	return $relic_edd_store_classes;
}
add_filter( 'body_class', 'relic_edd_store_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function relic_edd_store_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'relic_edd_store_pingback_header' );

/**
 * Gets the request parameter.
 *
 * @param      string  $key      The query parameter
 * @param      string  $default  The default value to return if not found
 *
 * @return     string  The request parameter.
 */

function relic_edd_store_get_request_parameter( $key, $default = '' ) {
    // If not request set
    if ( ! isset( $_REQUEST[ $key ] ) || empty( $_REQUEST[ $key ] ) ) {
        return $default;
    }

    // Set so process it
    return strip_tags( sanitize_text_field( wp_unslash( $_REQUEST[ $key ] ) ) );
}